/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2014  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.02a                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c 
Purpose : BSP for Microchip Explorer 16 eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT         6
#define LED1_BIT         7
#define LEDPORT_STATE    (*(volatile short*)0x02C4)
#define LEDPORT_LATCH    (*(volatile short*)0x02C0)
#define LED_LATCH        (*(volatile short*)0x02C4)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  LEDPORT_LATCH &= ~((1u << LED0_BIT) | (1u << LED1_BIT));
  LED_LATCH     &= ~((1u << LED0_BIT) | (1u << LED1_BIT));  
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  LED_LATCH |= (1u << (Index + LED0_BIT));
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  LED_LATCH &= ~(1u << (Index + LED0_BIT));
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (LEDPORT_STATE & (1u << (Index + LED0_BIT))) { 
    LED_LATCH &= ~(1u << (Index + LED0_BIT));           
  } else {
    LED_LATCH |= (1u << (Index + LED0_BIT));   
  }
}

/****** End Of File *************************************************/
